@@ -5,15 +5,11 @@ import os
 import genshi
 import genshi.template
 
-from trytond.pool import PoolMeta
 from trytond.modules.account_payment_sepa import payment as sepa_payment
+from trytond.pool import PoolMeta
 
 
-__all__ = ['Journal', 'Group']
-
-
-class Journal:
-    __metaclass__ = PoolMeta
+class Journal(metaclass=PoolMeta):
     __name__ = 'account.payment.journal'
 
     @classmethod
@@ -30,6 +26,7 @@ class Journal:
             if flavor not in field.selection:
                 field.selection.append(flavor)
 
+
 loader = genshi.template.TemplateLoader([
         os.path.join(os.path.dirname(__file__), 'template'),
         os.path.join(
@@ -38,8 +35,7 @@ loader = genshi.template.TemplateLoader([
         ], auto_reload=True)
 
 
-class Group:
-    __metaclass__ = PoolMeta
+class Group(metaclass=PoolMeta):
     __name__ = 'account.payment.group'
 
     def get_sepa_template(self):
